Wraps aws_nitro_enclaves_nsm_api to allow you to mock the Nitro Hypervisor locally
Modules
- api
- driver
driveris the primary entry point fornsm-nitro-enclave-utils’ server-side behavior.- pcr
- Contains a collection of utilities for working with Platform Configuration Registers (PCRs).
The primary goal here is to achieve stronger type safety when working with PCRs, as well as provide abstractions to generate
Pcrsthat you can use when self-signing your own attestation documents. - time
Structs
- Error
- Captures errors that can occur during attestation document verification.
kindis a high-level categorization of the error that is defined by the library.sourceis the underlying error that caused the failure. When possible, the source is the error that was returned by the underlying library. If the error returned from the underlying library does not implementstd::error::Error, or the error originated due to this library’s own assertions,ErrorContextis used. - Error
Context - Used by errors to provide additional context if the error returned from the underlying library does not implement
std::error::Error, or the error originated due to this library’s own assertions.