#[repr(C)]pub enum ErrorCode {
Success = 0,
InvalidArgument = 1,
InvalidIndex = 2,
InvalidResponse = 3,
ReadOnlyIndex = 4,
InvalidOperation = 5,
BufferTooSmall = 6,
InputTooLarge = 7,
InternalError = 8,
}Expand description
List of error codes that the NSM module can return as part of a Response
Variants
Success = 0
No errors
InvalidArgument = 1
Input argument(s) invalid
InvalidIndex = 2
PlatformConfigurationRegister index out of bounds
InvalidResponse = 3
The received response does not correspond to the earlier request
ReadOnlyIndex = 4
PlatformConfigurationRegister is in read-only mode and the operation attempted to modify it
InvalidOperation = 5
Given request cannot be fulfilled due to missing capabilities
BufferTooSmall = 6
Operation succeeded but provided output buffer is too small
InputTooLarge = 7
The user-provided input is too large
InternalError = 8
NitroSecureModule cannot fulfill request due to internal errors